==> eiffelstudio-16.05.tar: F_code/C6/ev251.c <==
/*
 * Code for class EV_STOCK_PIXMAPS_IMP
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ev251.h"
#include "ev_c_util.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EV_STOCK_PIXMAPS_IMP}.information_pixmap */
EIF_REFERENCE F504_4226 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLR(2,tr3);
	RTLR(3,Current);
	RTLR(4,Result);
	RTLIU(5);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1016, 0x00).id, 1016, _OBJSIZ_6_3_0_1_0_0_0_0_);
	tr2 = RTLNS(eif_new_type(800, 0x00).id, 800, _OBJSIZ_0_1_0_1_0_1_0_0_);
	tr3 = RTMS_EX_H("gtk-dialog-info",15,2003234927);
	F801_5474(RTCW(tr2), tr3);
	tr2 = F504_4235(Current, tr2);
	F1017_9026(RTCW(tr1), tr2);
	Result = (EIF_REFERENCE) tr1;
	RTLE;
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.error_pixmap */
EIF_REFERENCE F504_4227 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLR(2,tr3);
	RTLR(3,Current);
	RTLR(4,Result);
	RTLIU(5);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1016, 0x00).id, 1016, _OBJSIZ_6_3_0_1_0_0_0_0_);
	tr2 = RTLNS(eif_new_type(800, 0x00).id, 800, _OBJSIZ_0_1_0_1_0_1_0_0_);
	tr3 = RTMS_EX_H("gtk-dialog-error",16,1795811698);
	F801_5474(RTCW(tr2), tr3);
	tr2 = F504_4235(Current, tr2);
	F1017_9026(RTCW(tr1), tr2);
	Result = (EIF_REFERENCE) tr1;
	RTLE;
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.default_window_icon */
EIF_REFERENCE F504_4234 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,tr1);
	RTLR(1,Result);
	RTLR(2,loc1);
	RTLIU(3);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1016, 0x00).id, 1016, _OBJSIZ_6_3_0_1_0_0_0_0_);
	F955_8124(RTCW(tr1));
	Result = (EIF_REFERENCE) tr1;
	loc1 = *(EIF_REFERENCE *)(RTCW(Result) + _REFACS_3_);
	F1228_12333(RTCW(loc1));
	RTLE;
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.pixmap_from_stock_id */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
EIF_REFERENCE F504_4235 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTED;
	EIF_REFERENCE EIF_VOLATILE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE EIF_VOLATILE loc2 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN EIF_VOLATILE loc3 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_POINTER  EIF_VOLATILE tp1;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	RTXD;
	
	RTLI(6);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLR(4,loc2);
	RTLR(5,saved_except);
	RTLIU(6);
	RTXSLS;
	
	RTEV;
	RTGC;
	RTE_T
	if ((EIF_BOOLEAN) !loc3) {
		loc1 = (EIF_REFERENCE) arg1;
		tr1 = RTLNS(eif_new_type(958, 0x00).id, 958, _OBJSIZ_3_0_0_0_0_0_0_0_);
		F955_8124(RTCW(tr1));
		Result = (EIF_REFERENCE) tr1;
		loc2 = *(EIF_REFERENCE *)(RTCW(Result) + _REFACS_1_);
		loc2 = RTRV(eif_new_type(1063, 0x00), loc2);
		RTCT0(NULL, EX_CHECK);
		if ((EIF_BOOLEAN)(loc2 != NULL)) {
			RTCK0;
		} else {
			RTCF0;
		}
		tp1 = *(EIF_POINTER *)(RTCW(loc1)+ _PTROFF_0_1_0_1_0_0_);
		F1064_9573(RTCW(loc2), tp1);
	} else {
		tr1 = RTLNS(eif_new_type(958, 0x00).id, 958, _OBJSIZ_3_0_0_0_0_0_0_0_);
		F955_8124(RTCW(tr1));
		Result = (EIF_REFERENCE) tr1;
	}
	RTE_E
	RTXSC;
	loc3 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTER;
	/* NOTREACHED */
	RTE_EE
	RTEOK;
	RTLE;
	return Result;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

/* {EV_STOCK_PIXMAPS_IMP}.no_cursor_xpm */
EIF_POINTER F504_4248 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	
	Result = (EIF_POINTER) no_cursor_xpm();
	
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.sizenesw_cursor_xpm */
EIF_POINTER F504_4250 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	
	Result = (EIF_POINTER) sizenesw_cursor_xpm();
	
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.sizenwse_cursor_xpm */
EIF_POINTER F504_4252 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	
	Result = (EIF_POINTER) sizenwse_cursor_xpm();
	
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.sizewe_cursor_xpm */
EIF_POINTER F504_4253 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	
	Result = (EIF_POINTER) sizewe_cursor_xpm();
	
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.uparrow_cursor_xpm */
EIF_POINTER F504_4255 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	
	Result = (EIF_POINTER) uparrow_cursor_xpm();
	
	return Result;
}

void EIF_Minit251 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C6/ev251.c <==
/*
 * Code for class EV_STOCK_PIXMAPS_IMP
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ev251.h"
#include "ev_c_util.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EV_STOCK_PIXMAPS_IMP}.information_pixmap */
EIF_REFERENCE F289_4476 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLR(2,Current);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	Result = RTLNS(eif_new_type(1109, 0x00).id, 1109, _OBJSIZ_6_3_0_1_0_0_0_0_);
	tr1 = RTLNS(eif_new_type(865, 0x00).id, 865, _OBJSIZ_0_1_0_1_0_1_0_0_);
	tr2 = RTMS_EX_H("gtk-dialog-info",15,2003234927);
	F866_6231(RTCW(tr1), tr2);
	tr1 = F289_4485(Current, tr1);
	F1110_9783(RTCW(Result), tr1);
	RTLE;
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.error_pixmap */
EIF_REFERENCE F289_4477 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLR(2,Current);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	Result = RTLNS(eif_new_type(1109, 0x00).id, 1109, _OBJSIZ_6_3_0_1_0_0_0_0_);
	tr1 = RTLNS(eif_new_type(865, 0x00).id, 865, _OBJSIZ_0_1_0_1_0_1_0_0_);
	tr2 = RTMS_EX_H("gtk-dialog-error",16,1795811698);
	F866_6231(RTCW(tr1), tr2);
	tr1 = F289_4485(Current, tr1);
	F1110_9783(RTCW(Result), tr1);
	RTLE;
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.default_window_icon */
EIF_REFERENCE F289_4484 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Result);
	RTLR(1,loc1);
	RTLIU(2);
	
	RTGC;
	Result = RTLNS(eif_new_type(1109, 0x01).id, 1109, _OBJSIZ_6_3_0_1_0_0_0_0_);
	F1047_8864(RTCW(Result));
	loc1 = *(EIF_REFERENCE *)(RTCW(Result) + _REFACS_3_);
	F1332_13082(RTCW(loc1));
	RTLE;
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.pixmap_from_stock_id */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
EIF_REFERENCE F289_4485 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTED;
	EIF_REFERENCE EIF_VOLATILE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE EIF_VOLATILE loc2 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN EIF_VOLATILE loc3 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_POINTER  EIF_VOLATILE tp1;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	RTXD;
	
	RTLI(6);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLR(4,loc2);
	RTLR(5,saved_except);
	RTLIU(6);
	RTXSLS;
	
	RTEV;
	RTGC;
	RTE_T
	if ((EIF_BOOLEAN) !loc3) {
		loc1 = (EIF_REFERENCE) arg1;
		tr1 = RTLNS(eif_new_type(1051, 0x01).id, 1051, _OBJSIZ_3_0_0_0_0_0_0_0_);
		F1047_8864(RTCW(tr1));
		Result = (EIF_REFERENCE) tr1;
		loc2 = *(EIF_REFERENCE *)(RTCW(Result) + _REFACS_1_);
		loc2 = RTRV(eif_new_type(1161, 0x00), loc2);
		RTCT0("pixbuf_imp /= Void", EX_CHECK);
		if ((EIF_BOOLEAN)(loc2 != NULL)) {
			RTCK0;
		} else {
			RTCF0;
		}
		tp1 = *(EIF_POINTER *)(RTCW(loc1)+ _PTROFF_0_1_0_1_0_0_);
		F1162_10356(RTCW(loc2), tp1);
	} else {
		tr1 = RTLNS(eif_new_type(1051, 0x01).id, 1051, _OBJSIZ_3_0_0_0_0_0_0_0_);
		F1047_8864(RTCW(tr1));
		Result = (EIF_REFERENCE) tr1;
	}
	RTE_E
	RTXSC;
	loc3 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTER;
	/* NOTREACHED */
	RTE_EE
	RTEOK;
	RTLE;
	return Result;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

/* {EV_STOCK_PIXMAPS_IMP}.no_cursor_xpm */
EIF_POINTER F289_4498 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	
	Result = (EIF_POINTER) no_cursor_xpm();
	
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.sizenesw_cursor_xpm */
EIF_POINTER F289_4500 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	
	Result = (EIF_POINTER) sizenesw_cursor_xpm();
	
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.sizenwse_cursor_xpm */
EIF_POINTER F289_4502 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	
	Result = (EIF_POINTER) sizenwse_cursor_xpm();
	
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.sizewe_cursor_xpm */
EIF_POINTER F289_4503 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	
	Result = (EIF_POINTER) sizewe_cursor_xpm();
	
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.uparrow_cursor_xpm */
EIF_POINTER F289_4505 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	
	Result = (EIF_POINTER) uparrow_cursor_xpm();
	
	return Result;
}

void EIF_Minit251 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
